@@ -7,11 +7,9 @@ use pep508_rs::VerbatimUrl;
 use pypi_types::HashDigest;
 use uv_normalize::PackageName;
 
-use crate::direct_url::{LocalFileUrl, ParsedUrl};
-use crate::hash::Hashed;
 use crate::{
-    BuiltDist, Dist, DistributionMetadata, InstalledMetadata, InstalledVersion, Name, SourceDist,
-    VersionOrUrl,
+    BuiltDist, Dist, DistributionMetadata, Hashed, InstalledMetadata, InstalledVersion, Name,
+    ParsedLocalFileUrl, ParsedUrl, SourceDist, VersionOrUrl,
 };
 
 /// A built distribution (wheel) that exists in the local cache.
@@ -111,7 +109,7 @@ impl CachedDist {
             Self::Url(dist) => {
                 if dist.editable {
                     assert_eq!(dist.url.scheme(), "file", "{}", dist.url);
-                    Ok(Some(ParsedUrl::LocalFile(LocalFileUrl {
+                    Ok(Some(ParsedUrl::LocalFile(ParsedLocalFileUrl {
                         url: dist.url.raw().clone(),
                         editable: dist.editable,
                     })))
