@@ -2,12 +2,14 @@ use std::path::PathBuf;
 
 use anyhow::{Context, Result};
 use rustc_hash::FxHashSet;
-use tracing::{instrument, Level};
+use tracing::instrument;
 
 use cache_key::CanonicalUrl;
 use distribution_types::{FlatIndexLocation, IndexUrl};
-use pep508_rs::{Requirement, RequirementsTxtRequirement};
-use requirements_txt::{EditableRequirement, FindLink, RequirementsTxt};
+use pep508_rs::Requirement;
+use requirements_txt::{
+    EditableRequirement, FindLink, RequirementEntry, RequirementsTxt, RequirementsTxtRequirement,
+};
 use uv_client::BaseClientBuilder;
 use uv_configuration::{NoBinary, NoBuild};
 use uv_fs::Simplified;
@@ -21,11 +23,11 @@ pub struct RequirementsSpecification {
     /// The name of the project specifying requirements.
     pub project: Option<PackageName>,
     /// The requirements for the project.
-    pub requirements: Vec<RequirementsTxtRequirement>,
+    pub requirements: Vec<RequirementEntry>,
     /// The constraints for the project.
     pub constraints: Vec<Requirement>,
     /// The overrides for the project.
-    pub overrides: Vec<Requirement>,
+    pub overrides: Vec<RequirementEntry>,
     /// Package to install as editable installs
     pub editables: Vec<EditableRequirement>,
     /// The source trees from which to extract requirements.
@@ -48,10 +50,10 @@ pub struct RequirementsSpecification {
 
 impl RequirementsSpecification {
     /// Read the requirements and constraints from a source.
-    #[instrument(skip_all, level = Level::DEBUG, fields(source = % source))]
+    #[instrument(skip_all, level = tracing::Level::DEBUG, fields(source = % source))]
     pub async fn from_source(
         source: &RequirementsSource,
-        extras: &ExtrasSpecification<'_>,
+        extras: &ExtrasSpecification,
         client_builder: &BaseClientBuilder<'_>,
     ) -> Result<Self> {
         Ok(match source {
@@ -60,7 +62,10 @@ impl RequirementsSpecification {
                     .with_context(|| format!("Failed to parse `{name}`"))?;
                 Self {
                     project: None,
-                    requirements: vec![requirement],
+                    requirements: vec![RequirementEntry {
+                        requirement,
+                        hashes: vec![],
+                    }],
                     constraints: vec![],
                     overrides: vec![],
                     editables: vec![],
@@ -98,11 +103,7 @@ impl RequirementsSpecification {
                     RequirementsTxt::parse(path, std::env::current_dir()?, client_builder).await?;
                 Self {
                     project: None,
-                    requirements: requirements_txt
-                        .requirements
-                        .into_iter()
-                        .map(|entry| entry.requirement)
-                        .collect(),
+                    requirements: requirements_txt.requirements,
                     constraints: requirements_txt.constraints,
                     overrides: vec![],
                     editables: requirements_txt.editables,
@@ -151,7 +152,10 @@ impl RequirementsSpecification {
                         requirements: project
                             .requirements
                             .into_iter()
-                            .map(RequirementsTxtRequirement::Pep508)
+                            .map(|requirement| RequirementEntry {
+                                requirement: RequirementsTxtRequirement::Pep508(requirement),
+                                hashes: vec![],
+                            })
                             .collect(),
                         constraints: vec![],
                         overrides: vec![],
@@ -222,7 +226,7 @@ impl RequirementsSpecification {
         requirements: &[RequirementsSource],
         constraints: &[RequirementsSource],
         overrides: &[RequirementsSource],
-        extras: &ExtrasSpecification<'_>,
+        extras: &ExtrasSpecification,
         client_builder: &BaseClientBuilder<'_>,
     ) -> Result<Self> {
         let mut spec = Self::default();
@@ -261,11 +265,12 @@ impl RequirementsSpecification {
             spec.no_build.extend(source.no_build);
         }
 
-        // Read all constraints, treating _everything_ as a constraint.
+        // Read all constraints, treating both requirements _and_ constraints as constraints.
+        // Overrides are ignored, as are the hashes, as they are not relevant for constraints.
         for source in constraints {
             let source = Self::from_source(source, extras, client_builder).await?;
-            for requirement in source.requirements {
-                match requirement {
+            for entry in source.requirements {
+                match entry.requirement {
                     RequirementsTxtRequirement::Pep508(requirement) => {
                         spec.constraints.push(requirement);
                     }
@@ -277,7 +282,6 @@ impl RequirementsSpecification {
                 }
             }
             spec.constraints.extend(source.constraints);
-            spec.constraints.extend(source.overrides);
 
             if let Some(index_url) = source.index_url {
                 if let Some(existing) = spec.index_url {
@@ -296,22 +300,11 @@ impl RequirementsSpecification {
             spec.no_build.extend(source.no_build);
         }
 
-        // Read all overrides, treating both requirements _and_ constraints as overrides.
+        // Read all overrides, treating both requirements _and_ overrides as overrides.
+        // Constraints are ignored.
         for source in overrides {
             let source = Self::from_source(source, extras, client_builder).await?;
-            for requirement in source.requirements {
-                match requirement {
-                    RequirementsTxtRequirement::Pep508(requirement) => {
-                        spec.overrides.push(requirement);
-                    }
-                    RequirementsTxtRequirement::Unnamed(requirement) => {
-                        return Err(anyhow::anyhow!(
-                            "Unnamed requirements are not allowed as overrides (found: `{requirement}`)"
-                        ));
-                    }
-                }
-            }
-            spec.overrides.extend(source.constraints);
+            spec.overrides.extend(source.requirements);
             spec.overrides.extend(source.overrides);
 
             if let Some(index_url) = source.index_url {
