@@ -3,10 +3,16 @@ use rustc_hash::FxHashSet;
 use pep508_rs::{MarkerEnvironment, VersionOrUrl};
 use uv_normalize::PackageName;
 
-use crate::Manifest;
+use crate::{DependencyMode, Manifest};
 
 #[derive(Debug, Default, Clone, Copy, PartialEq, Eq)]
 #[cfg_attr(feature = "clap", derive(clap::ValueEnum))]
+#[cfg_attr(feature = "serde", derive(serde::Deserialize))]
+#[cfg_attr(
+    feature = "serde",
+    serde(deny_unknown_fields, rename_all = "kebab-case")
+)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 pub enum PreReleaseMode {
     /// Disallow all pre-release versions.
     Disallow,
@@ -54,6 +60,7 @@ impl PreReleaseStrategy {
         mode: PreReleaseMode,
         manifest: &Manifest,
         markers: &MarkerEnvironment,
+        dependencies: DependencyMode,
     ) -> Self {
         match mode {
             PreReleaseMode::Disallow => Self::Disallow,
@@ -61,16 +68,7 @@ impl PreReleaseStrategy {
             PreReleaseMode::IfNecessary => Self::IfNecessary,
             PreReleaseMode::Explicit => Self::Explicit(
                 manifest
-                    .requirements
-                    .iter()
-                    .chain(manifest.constraints.iter())
-                    .chain(manifest.overrides.iter())
-                    .filter(|requirement| requirement.evaluate_markers(markers, &[]))
-                    .chain(manifest.editables.iter().flat_map(|(editable, metadata)| {
-                        metadata.requires_dist.iter().filter(|requirement| {
-                            requirement.evaluate_markers(markers, &editable.extras)
-                        })
-                    }))
+                    .requirements(markers, dependencies)
                     .filter(|requirement| {
                         let Some(version_or_url) = &requirement.version_or_url else {
                             return false;
@@ -90,16 +88,7 @@ impl PreReleaseStrategy {
             ),
             PreReleaseMode::IfNecessaryOrExplicit => Self::IfNecessaryOrExplicit(
                 manifest
-                    .requirements
-                    .iter()
-                    .chain(manifest.constraints.iter())
-                    .chain(manifest.overrides.iter())
-                    .filter(|requirement| requirement.evaluate_markers(markers, &[]))
-                    .chain(manifest.editables.iter().flat_map(|(editable, metadata)| {
-                        metadata.requires_dist.iter().filter(|requirement| {
-                            requirement.evaluate_markers(markers, &editable.extras)
-                        })
-                    }))
+                    .requirements(markers, dependencies)
                     .filter(|requirement| {
                         let Some(version_or_url) = &requirement.version_or_url else {
                             return false;
