@@ -61,13 +61,31 @@ pub enum PubGrubPackage {
         /// _after_ a registry variant.
         Option<VerbatimUrl>,
     ),
+    /// A proxy package to represent a dependency with an extra (e.g., `black[colorama]`).
+    ///
+    /// For a given package `black`, and an extra `colorama`, we create a virtual package
+    /// with exactly two dependencies: `PubGrubPackage::Package("black", None)` and
+    /// `PubGrubPackage::Package("black", Some("colorama")`. Both dependencies are pinned to the
+    /// same version, and the virtual package is discarded at the end of the resolution process.
+    ///
+    /// The benefit of the proxy package (versus `PubGrubPackage::Package("black", Some("colorama")`
+    /// on its own) is that it enables us to avoid attempting to retrieve metadata for irrelevant
+    /// versions the extra variants by making it clear to PubGrub that the extra variant must match
+    /// the exact same version of the base variant. Without the proxy package, then when provided
+    /// requirements like `black==23.0.1` and `black[colorama]`, PubGrub may attempt to retrieve
+    /// metadata for `black[colorama]` versions other than `23.0.1`.
+    Extra(PackageName, ExtraName, Option<VerbatimUrl>),
 }
 
 impl PubGrubPackage {
     /// Create a [`PubGrubPackage`] from a package name and optional extra name.
     pub(crate) fn from_package(name: PackageName, extra: Option<ExtraName>, urls: &Urls) -> Self {
         let url = urls.get(&name).cloned();
-        Self::Package(name, extra, url)
+        if let Some(extra) = extra {
+            Self::Extra(name, extra, url)
+        } else {
+            Self::Package(name, extra, url)
+        }
     }
 }
 
@@ -82,18 +100,19 @@ pub enum PubGrubPython {
 impl std::fmt::Display for PubGrubPackage {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            PubGrubPackage::Root(name) => {
+            Self::Root(name) => {
                 if let Some(name) = name {
                     write!(f, "{}", name.as_ref())
                 } else {
                     write!(f, "root")
                 }
             }
-            PubGrubPackage::Python(_) => write!(f, "Python"),
-            PubGrubPackage::Package(name, None, ..) => write!(f, "{name}"),
-            PubGrubPackage::Package(name, Some(extra), ..) => {
+            Self::Python(_) => write!(f, "Python"),
+            Self::Package(name, None, ..) => write!(f, "{name}"),
+            Self::Package(name, Some(extra), ..) => {
                 write!(f, "{name}[{extra}]")
             }
+            Self::Extra(name, extra, ..) => write!(f, "{name}[{extra}]"),
         }
     }
 }
