@@ -1,19 +1,20 @@
 use std::future::Future;
 
 use anyhow::Result;
-use chrono::{DateTime, Utc};
 
 use distribution_types::{Dist, IndexLocations};
 use platform_tags::Tags;
-use pypi_types::Metadata23;
-use uv_client::{FlatIndex, RegistryClient};
-use uv_distribution::DistributionDatabase;
+use uv_client::RegistryClient;
+use uv_configuration::{NoBinary, NoBuild};
+use uv_distribution::{ArchiveMetadata, DistributionDatabase};
 use uv_normalize::PackageName;
-use uv_types::{BuildContext, NoBinary, NoBuild};
+use uv_types::{BuildContext, HashStrategy};
 
+use crate::flat_index::FlatIndex;
 use crate::python_requirement::PythonRequirement;
 use crate::version_map::VersionMap;
 use crate::yanks::AllowedYanks;
+use crate::ExcludeNewer;
 
 pub type PackageVersionsResult = Result<VersionsResponse, uv_client::Error>;
 pub type WheelMetadataResult = Result<MetadataResponse, uv_distribution::Error>;
@@ -34,9 +35,11 @@ pub enum VersionsResponse {
 #[derive(Debug)]
 pub enum MetadataResponse {
     /// The wheel metadata was found and parsed successfully.
-    Found(Metadata23),
+    Found(ArchiveMetadata),
     /// The wheel metadata was found, but could not be parsed.
     InvalidMetadata(Box<pypi_types::MetadataError>),
+    /// The wheel metadata was found, but the metadata was inconsistent.
+    InconsistentMetadata(Box<uv_distribution::Error>),
     /// The wheel has an invalid structure.
     InvalidStructure(Box<install_wheel_rs::Error>),
     /// The wheel metadata was not found in the cache and the network is not available.
@@ -79,7 +82,8 @@ pub struct DefaultResolverProvider<'a, Context: BuildContext + Send + Sync> {
     tags: Tags,
     python_requirement: PythonRequirement,
     allowed_yanks: AllowedYanks,
-    exclude_newer: Option<DateTime<Utc>>,
+    hasher: HashStrategy,
+    exclude_newer: Option<ExcludeNewer>,
     no_binary: NoBinary,
     no_build: NoBuild,
 }
@@ -94,7 +98,8 @@ impl<'a, Context: BuildContext + Send + Sync> DefaultResolverProvider<'a, Contex
         tags: &'a Tags,
         python_requirement: PythonRequirement,
         allowed_yanks: AllowedYanks,
-        exclude_newer: Option<DateTime<Utc>>,
+        hasher: &'a HashStrategy,
+        exclude_newer: Option<ExcludeNewer>,
         no_binary: &'a NoBinary,
         no_build: &'a NoBuild,
     ) -> Self {
@@ -105,6 +110,7 @@ impl<'a, Context: BuildContext + Send + Sync> DefaultResolverProvider<'a, Contex
             tags: tags.clone(),
             python_requirement,
             allowed_yanks,
+            hasher: hasher.clone(),
             exclude_newer,
             no_binary: no_binary.clone(),
             no_build: no_build.clone(),
@@ -132,6 +138,7 @@ impl<'a, Context: BuildContext + Send + Sync> ResolverProvider
                             &self.tags,
                             &self.python_requirement,
                             &self.allowed_yanks,
+                            &self.hasher,
                             self.exclude_newer.as_ref(),
                             self.flat_index.get(package_name).cloned(),
                             &self.no_binary,
@@ -171,7 +178,11 @@ impl<'a, Context: BuildContext + Send + Sync> ResolverProvider
 
     /// Fetch the metadata for a distribution, building it if necessary.
     async fn get_or_build_wheel_metadata<'io>(&'io self, dist: &'io Dist) -> WheelMetadataResult {
-        match self.fetcher.get_or_build_wheel_metadata(dist).await {
+        match self
+            .fetcher
+            .get_or_build_wheel_metadata(dist, self.hasher.get(dist))
+            .await
+        {
             Ok(metadata) => Ok(MetadataResponse::Found(metadata)),
             Err(err) => match err {
                 uv_distribution::Error::Client(client) => match client.into_kind() {
@@ -184,6 +195,12 @@ impl<'a, Context: BuildContext + Send + Sync> ResolverProvider
                     }
                     kind => Err(uv_client::Error::from(kind).into()),
                 },
+                uv_distribution::Error::VersionMismatch { .. } => {
+                    Ok(MetadataResponse::InconsistentMetadata(Box::new(err)))
+                }
+                uv_distribution::Error::NameMismatch { .. } => {
+                    Ok(MetadataResponse::InconsistentMetadata(Box::new(err)))
+                }
                 uv_distribution::Error::Metadata(err) => {
                     Ok(MetadataResponse::InvalidMetadata(Box::new(err)))
                 }
