@@ -1,3 +1,4 @@
+use std::ffi::OsString;
 use std::path::PathBuf;
 
 use distribution_types::IndexLocations;
@@ -5,9 +6,10 @@ use install_wheel_rs::linker::LinkMode;
 use uv_cache::{CacheArgs, Refresh};
 use uv_client::Connectivity;
 use uv_configuration::{
-    ConfigSettings, IndexStrategy, KeyringProviderType, NoBinary, NoBuild, Reinstall,
+    ConfigSettings, IndexStrategy, KeyringProviderType, NoBinary, NoBuild, PreviewMode, Reinstall,
     SetupPyStrategy, TargetTriple, Upgrade,
 };
+use uv_interpreter::Target;
 use uv_normalize::PackageName;
 use uv_requirements::ExtrasSpecification;
 use uv_resolver::{AnnotationStyle, DependencyMode, ExcludeNewer, PreReleaseMode, ResolutionMode};
@@ -16,7 +18,7 @@ use uv_workspace::{PipOptions, Workspace};
 
 use crate::cli::{
     ColorChoice, GlobalArgs, Maybe, PipCheckArgs, PipCompileArgs, PipFreezeArgs, PipInstallArgs,
-    PipListArgs, PipShowArgs, PipSyncArgs, PipUninstallArgs, VenvArgs,
+    PipListArgs, PipShowArgs, PipSyncArgs, PipUninstallArgs, RunArgs, VenvArgs,
 };
 use crate::commands::ListFormat;
 
@@ -28,6 +30,7 @@ pub(crate) struct GlobalSettings {
     pub(crate) verbose: u8,
     pub(crate) color: ColorChoice,
     pub(crate) native_tls: bool,
+    pub(crate) preview: PreviewMode,
 }
 
 impl GlobalSettings {
@@ -44,6 +47,11 @@ impl GlobalSettings {
             native_tls: flag(args.native_tls, args.no_native_tls)
                 .or(workspace.and_then(|workspace| workspace.options.native_tls))
                 .unwrap_or(false),
+            preview: PreviewMode::from(
+                flag(args.preview, args.no_preview)
+                    .or(workspace.and_then(|workspace| workspace.options.preview))
+                    .unwrap_or(false),
+            ),
         }
     }
 }
@@ -71,6 +79,44 @@ impl CacheSettings {
     }
 }
 
+/// The resolved settings to use for a `run` invocation.
+#[allow(clippy::struct_excessive_bools)]
+#[derive(Debug, Clone)]
+pub(crate) struct RunSettings {
+    // CLI-only settings.
+    pub(crate) target: Option<String>,
+    pub(crate) args: Vec<OsString>,
+    pub(crate) isolated: bool,
+    pub(crate) with: Vec<String>,
+    pub(crate) no_workspace: bool,
+    pub(crate) python: Option<String>,
+}
+
+impl RunSettings {
+    /// Resolve the [`RunSettings`] from the CLI and workspace configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: RunArgs, _workspace: Option<Workspace>) -> Self {
+        let RunArgs {
+            target,
+            args,
+            isolated,
+            with,
+            no_workspace,
+            python,
+        } = args;
+
+        Self {
+            // CLI-only settings.
+            target,
+            args,
+            isolated,
+            with,
+            no_workspace,
+            python,
+        }
+    }
+}
+
 /// The resolved settings to use for a `pip compile` invocation.
 #[allow(clippy::struct_excessive_bools)]
 #[derive(Debug, Clone)]
@@ -257,6 +303,7 @@ impl PipSyncSettings {
             no_system,
             break_system_packages,
             no_break_system_packages,
+            target,
             legacy_setup_py,
             no_legacy_setup_py,
             no_build_isolation,
@@ -268,6 +315,8 @@ impl PipSyncSettings {
             compile_bytecode,
             no_compile_bytecode,
             config_setting,
+            python_version,
+            python_platform,
             strict,
             no_strict,
             compat_args: _,
@@ -285,6 +334,7 @@ impl PipSyncSettings {
                     python,
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
+                    target,
                     offline: flag(offline, no_offline),
                     index_url: index_url.and_then(Maybe::into_option),
                     extra_index_url: extra_index_url.map(|extra_index_urls| {
@@ -306,6 +356,8 @@ impl PipSyncSettings {
                     config_settings: config_setting.map(|config_settings| {
                         config_settings.into_iter().collect::<ConfigSettings>()
                     }),
+                    python_version,
+                    python_platform,
                     link_mode,
                     compile_bytecode: flag(compile_bytecode, no_compile_bytecode),
                     require_hashes: flag(require_hashes, no_require_hashes),
@@ -374,6 +426,7 @@ impl PipInstallSettings {
             no_system,
             break_system_packages,
             no_break_system_packages,
+            target,
             legacy_setup_py,
             no_legacy_setup_py,
             no_build_isolation,
@@ -385,6 +438,8 @@ impl PipInstallSettings {
             compile_bytecode,
             no_compile_bytecode,
             config_setting,
+            python_version,
+            python_platform,
             strict,
             no_strict,
             exclude_newer,
@@ -412,6 +467,7 @@ impl PipInstallSettings {
                     python,
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
+                    target,
                     offline: flag(offline, no_offline),
                     index_url: index_url.and_then(Maybe::into_option),
                     extra_index_url: extra_index_url.map(|extra_index_urls| {
@@ -442,6 +498,8 @@ impl PipInstallSettings {
                     config_settings: config_setting.map(|config_settings| {
                         config_settings.into_iter().collect::<ConfigSettings>()
                     }),
+                    python_version,
+                    python_platform,
                     exclude_newer,
                     link_mode,
                     compile_bytecode: flag(compile_bytecode, no_compile_bytecode),
@@ -477,6 +535,7 @@ impl PipUninstallSettings {
             no_system,
             break_system_packages,
             no_break_system_packages,
+            target,
             offline,
             no_offline,
         } = args;
@@ -492,6 +551,7 @@ impl PipUninstallSettings {
                     python,
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
+                    target,
                     offline: flag(offline, no_offline),
                     keyring_provider,
                     ..PipOptions::default()
@@ -748,6 +808,7 @@ pub(crate) struct PipSharedSettings {
     pub(crate) system: bool,
     pub(crate) extras: ExtrasSpecification,
     pub(crate) break_system_packages: bool,
+    pub(crate) target: Option<Target>,
     pub(crate) connectivity: Connectivity,
     pub(crate) index_strategy: IndexStrategy,
     pub(crate) keyring_provider: KeyringProviderType,
@@ -787,6 +848,7 @@ impl PipSharedSettings {
             python,
             system,
             break_system_packages,
+            target,
             offline,
             index_url,
             extra_index_url,
@@ -902,6 +964,7 @@ impl PipSharedSettings {
                 .break_system_packages
                 .or(break_system_packages)
                 .unwrap_or_default(),
+            target: args.target.or(target).map(Target::from),
             no_binary: NoBinary::from_args(args.no_binary.or(no_binary).unwrap_or_default()),
             compile_bytecode: args
                 .compile_bytecode
